You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tapestry.apache.org by hl...@apache.org on 2011/10/13 21:18:05 UTC

svn commit: r1183040 - /tapestry/tapestry5/trunk/tapestry-func/src/main/java/org/apache/tapestry5/func/Reducer.java

Author: hlship
Date: Thu Oct 13 19:18:05 2011
New Revision: 1183040

URL: http://svn.apache.org/viewvc?rev=1183040&view=rev
Log:
Rename parameter "value" to "element" for consistency

Modified:
    tapestry/tapestry5/trunk/tapestry-func/src/main/java/org/apache/tapestry5/func/Reducer.java

Modified: tapestry/tapestry5/trunk/tapestry-func/src/main/java/org/apache/tapestry5/func/Reducer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-func/src/main/java/org/apache/tapestry5/func/Reducer.java?rev=1183040&r1=1183039&r2=1183040&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-func/src/main/java/org/apache/tapestry5/func/Reducer.java (original)
+++ tapestry/tapestry5/trunk/tapestry-func/src/main/java/org/apache/tapestry5/func/Reducer.java Thu Oct 13 19:18:05 2011
@@ -25,8 +25,8 @@ package org.apache.tapestry5.func;
 public interface Reducer<A, T>
 {
     /**
      * Run a computation using the current value of the accumulator and a value (from a Flow),
      * and return the new accumulator.
      */
-    A reduce(A accumulator, T value);
+    A reduce(A accumulator, T element);
 }
@@ -25,8 +25,8 @@ package org.apache.tapestry5.func;
 {
     /**
-     * Run a computation using the current value of the accumulator and a value (from a Flow),
+     * Run a computation using the current value of the accumulator and an element (from a Flow),
      * and return the new accumulator.
      */